@@ -63,8 +63,14 @@ class Bot:
     @property
     def print(self) -> Callable:
         def print_(*values: Any, sep: str = " ", end: str = "") -> None:
-            message = sep.join(map(str, values)) + end
+            if not values:
+                return
 
+            message = sep.join(map(str, values)) + end
+            
+            if not message:
+                return
+                
             if self.replace_ansi:
                 message = re.sub(r"\x1B[@-_][0-?]*[ -/]*[@-~]", "", message)
                 
